# django-canto
A simple client for python with django integration that 
allows you to integrate cantos DAM.

## FIXME Getting started
Add `canto` to your `INSTALLED_APPS` 

- add urls
- permissions
- customize / import example
